ColorButton — pyqtgraph 0.11.0rc0 documentation

# ColorButton

class `pyqtgraph.` `ColorButton`(parent=None, color=(128, 128, 128))

  Bases: QtGui.QPushButton

  Button displaying a color and allowing the user to select a new color.

  Signals: |
  sigColorChanging(self) | emitted whenever a new color is picked in the color dialog
  sigColorChanged(self) | emitted when the selected color is accepted (user clicks OK)

  `__init__`(parent=None, color=(128, 128, 128))

    Initialize self. See help(type(self)) for accurate signature.

  `paintEvent`(self, arg__1: PySide2.QtGui.QPaintEvent)
  `setColor`(color, finished=True)

    Sets the button’s color and emits both sigColorChanged and sigColorChanging.